@@ -1,6 +1,6 @@
 """Entry point for the CLI (Init of parser)"""
 
-#!/usr/bin/python3
+#!/usr/bin/python3 # noqa: E265
 import argparse
 
 from .apps import AppsCommmand
@@ -11,7 +11,9 @@ from .scaffold import CreateCommand
 
 def main():
     parser = argparse.ArgumentParser(
-        description="deepchain cli", add_help=True, usage="deepchain <command> [<args>]"
+        description="deepchain CLI",
+        add_help=True,
+        usage="deepchain <command> [--<args>] [<arguments>]",
     )
     commands_parser = parser.add_subparsers(help="deepchain-cli command helpers")
 
@@ -21,6 +23,11 @@ def main():
     AppsCommmand.register_subcommand(commands_parser)
 
     args = parser.parse_args()
+
+    if not hasattr(args, "func"):
+        parser.print_help()
+        exit(1)
+
     service = args.func(args)
     service.run()
 
