@@ -27,7 +27,7 @@ class MLP(TorchModel):
         self.output = nn.Softmax if output_shape > 1 else nn.Sigmoid
         self.loss = F.cross_entropy if output_shape > 1 else F.binary_cross_entropy
         self._model = nn.Sequential(
-            nn.Linear(input_shape, 128), nn.ReLU(), nn.Linear(128, 1), self.output()
+            nn.Linear(input_shape, 128), nn.ReLU(), nn.Linear(128, output_shape), self.output()
         )
 
     def forward(self, x):
